@@ -42,7 +42,7 @@ func testSetupTeardown(t *testing.T) (artifact, sdimg, fatsdimg string, f func()
 	err = copyFile("mender_test.img", filepath.Join(tmp, "mender_test.img"))
 	assert.NoError(t, err)
 
-	err = WriteArtifact(tmp, 2, filepath.Join(tmp, "mender_test.img"))
+	err = WriteArtifact(tmp, LatestFormatVersion, filepath.Join(tmp, "mender_test.img"))
 	assert.NoError(t, err)
 	artifact = filepath.Join(tmp, "artifact.mender")
 
@@ -125,7 +125,17 @@ func TestCLIErrors(t *testing.T) {
 		{
 			name: "Install: Error on  wrong number of arguments given",
 			argv: []string{"mender-artifact", "install", "foo.txt", "bar.txt", ":/some/path/file.txt"},
-			err:  "got 3 arguments, wants two",
+			err:  "Wrong number of arguments, got 3",
+		},
+		{
+			name: "Install: Error on wrong number of arguments given to directory install",
+			argv: []string{"mender-artifact", "install", "-d", "foo.txt", ":/some/path/file.txt"},
+			err:  "Wrong number of arguments, got 2",
+		},
+		{
+			name: "Install: Error on parse error for directory install",
+			argv: []string{"mender-artifact", "install", "-d", "foo.txt"},
+			err:  "No artifact or sdimg provided",
 		},
 	}
 
@@ -619,6 +629,80 @@ func TestCopyRootfsImage(t *testing.T) {
 				}
 			},
 		},
+		{
+			name: "Make sure that rootfs_image_checksum is updated when repacking Artifact",
+			initfunc: func(imgpath string) {
+				require.Nil(t, ioutil.WriteFile("foo.txt", []byte("foobar"), 0644))
+			},
+			argv: []string{"mender-artifact", "cp", "foo.txt", "<artifact>:/etc/test.txt"},
+			verifyTestFunc: func(imgpath string) {
+				defer os.Remove("foo.txt")
+				// Read the artifact after cp.
+				readScripts := func(r io.Reader, info os.FileInfo) error {
+					return nil
+				}
+				f, err := os.Open(imgpath)
+				require.Nil(t, err)
+				defer f.Close()
+				ver := func(message, sig []byte) error {
+					return nil
+				}
+				ar := areader.NewReader(f)
+				ar.ScriptsReadCallback = readScripts
+				ar.VerifySignatureCallback = ver
+				err = ar.ReadArtifact()
+				require.Nil(t, err)
+				inst := ar.GetHandlers()
+
+				provides, err := inst[0].GetUpdateProvides()
+				require.NoError(t, err)
+				assert.Equal(t, string(inst[0].GetUpdateFiles()[0].Checksum), provides["rootfs_image_checksum"])
+			},
+		},
+		{
+			name: "Create a directory",
+			initfunc: func(imgpath string) {
+				require.Nil(t, ioutil.WriteFile("test.txt", []byte("foobar"), 0644))
+			},
+			argv: []string{"mender-artifact", "install", "-d", "<artifact|sdimg|fat-sdimg>:/foo"},
+			verifyTestFunc: func(imgpath string) {
+				os.Args = []string{"mender-artifact", "install", "-m", "0644", "test.txt", imgpath + ":/foo/test.txt"}
+				err := run()
+				assert.NoError(t, err)
+				cmd := exec.Command(filepath.Join(dir, "mender-artifact"), "cat", imgpath+":/foo/test.txt")
+				var out bytes.Buffer
+				cmd.Stdout = &out
+				err = cmd.Run()
+				assert.Nil(t, err, "got unexpected error: %v", err)
+				assert.Equal(t, "foobar", out.String())
+				// Cleanup the testkey
+				assert.Nil(t, os.Remove("test.txt"))
+			},
+		},
+		{
+			name: "Create nested directories",
+			initfunc: func(imgpath string) {
+				require.Nil(t, ioutil.WriteFile("test.txt", []byte("foobar"), 0644))
+			},
+			argv: []string{"mender-artifact", "install", "-d", "<artifact|sdimg|fat-sdimg>:/foo/bar"},
+			verifyTestFunc: func(imgpath string) {
+				os.Args = []string{"mender-artifact", "install", "-m", "0644", "test.txt", imgpath + ":/foo/bar/test.txt"}
+				err := run()
+				assert.NoError(t, err)
+				cmd := exec.Command(filepath.Join(dir, "mender-artifact"), "cat", imgpath+":/foo/bar/test.txt")
+				var out bytes.Buffer
+				cmd.Stdout = &out
+				err = cmd.Run()
+				assert.Nil(t, err, "got unexpected error: %v", err)
+				assert.Equal(t, "foobar", out.String())
+				// Cleanup the testkey
+				assert.Nil(t, os.Remove("test.txt"))
+			},
+		},
+		{
+			name: "Create a directory that already exists",
+			argv: []string{"mender-artifact", "install", "-d", "<artifact|sdimg|fat-sdimg>:/"},
+		},
 	}
 
 	for _, test := range tests {
@@ -708,6 +792,7 @@ func TestCopyRootfsImage(t *testing.T) {
 
 					if test.err != "" {
 						assert.Contains(t, err.Error(), test.err)
+						return
 					}
 
 					if err != nil {
