@@ -131,7 +131,10 @@ func writeRootfs(c *cli.Context) error {
 
 	f, err := os.Create(name + ".tmp")
 	if err != nil {
-		return cli.NewExitError("can not create artifact file", errArtifactCreate)
+		return cli.NewExitError(
+			"can not create artifact file: "+err.Error(),
+			errArtifactCreate,
+		)
 	}
 	defer func() {
 		f.Close()
@@ -379,6 +382,11 @@ func writeModuleImage(ctx *cli.Context) error {
 		return cli.NewExitError("Mender-Artifact version 1 is not supported", 1)
 	}
 
+	// The device-type flag is required
+	if len(ctx.StringSlice("device-type")) == 0 {
+		return cli.NewExitError("The `device-type` flag is required", 1)
+	}
+
 	upd, err := makeUpdates(ctx)
 	if err != nil {
 		return err
@@ -386,7 +394,10 @@ func writeModuleImage(ctx *cli.Context) error {
 
 	f, err := os.Create(name + ".tmp")
 	if err != nil {
-		return cli.NewExitError("can not create artifact file", errArtifactCreate)
+		return cli.NewExitError(
+			"can not create artifact file: "+err.Error(),
+			errArtifactCreate,
+		)
 	}
 	defer func() {
 		f.Close()
@@ -510,7 +521,7 @@ func getDeviceSnapshot(c *cli.Context) (string, error) {
 	// established (password prompt is written to /dev/tty directly,
 	// and hence impossible to detect).
 	args = append(args, "sudo", "-S", "/bin/sh", "-c",
-		`'echo "`+sshInitMagic+`"; mender snapshot dump | cat'`)
+		`'echo "`+sshInitMagic+`" && mender snapshot dump | cat'`)
 
 	cmd := exec.Command("ssh", args...)
 
@@ -529,33 +540,19 @@ func getDeviceSnapshot(c *cli.Context) (string, error) {
 	}
 	filePath := f.Name()
 
-	defer func() {
-		// Close sigChan only if still open
-		if sigChan != nil {
-			select {
-			case _, open := <-sigChan:
-				if open {
-					signal.Stop(sigChan)
-					close(sigChan)
-				}
-			default:
-				// No data ready on sigChan
-				signal.Stop(sigChan)
-				close(sigChan)
-			}
-		}
-		f.Close()
-	}()
+	defer removeOnPanic(filePath)
+	defer f.Close()
 
 	// Disable tty echo before starting
 	term, err := util.DisableEcho(int(os.Stdin.Fd()))
 	if err == nil {
 		sigChan = make(chan os.Signal)
 		errChan = make(chan error)
+		defer closeSigChanIfOpen(sigChan)
 		// Make sure that echo is enabled if the process gets
 		// interrupted
 		signal.Notify(sigChan)
-		go util.EchoSigHandler(sigChan, errChan, term, filePath)
+		go util.EchoSigHandler(sigChan, errChan, term)
 	} else if err != syscall.ENOTTY {
 		return "", err
 	}
@@ -672,3 +669,39 @@ func sizeStr(bytes int64) string {
 	}
 	return fmt.Sprintf("%d %s", tmp, suffixes[i])
 }
+
+func removeOnPanic(filename string) {
+	if r := recover(); r != nil {
+		err := os.Remove(filename)
+		if err != nil {
+			switch r.(type) {
+			case string:
+				err = errors.Wrap(errors.
+					New(r.(string)), err.Error())
+				panic(err)
+			case error:
+				err = errors.Wrap(r.(error), err.Error())
+			default:
+				panic(r)
+			}
+		}
+		panic(r)
+	}
+}
+
+func closeSigChanIfOpen(sigChan chan os.Signal) {
+	// Close sigChan only if still open
+	if sigChan != nil {
+		select {
+		case _, open := <-sigChan:
+			if open {
+				signal.Stop(sigChan)
+				close(sigChan)
+			}
+		default:
+			// No data ready on sigChan
+			signal.Stop(sigChan)
+			close(sigChan)
+		}
+	}
+}
