@@ -1,4 +1,4 @@
-// Copyright 2019 Northern.tech AS
+// Copyright 2020 Northern.tech AS
 //
 //    Licensed under the Apache License, Version 2.0 (the "License");
 //    you may not use this file except in compliance with the License.
@@ -177,7 +177,7 @@ func TestComposeHeader(t *testing.T) {
 			rfs: NewAugmentedRootfs(NewRootfsV3(""), ""),
 			args: ComposeHeaderArgs{
 				TarWriter:  tar.NewWriter(bytes.NewBuffer(nil)),
-				TypeInfoV3: &artifact.TypeInfoV3{ArtifactProvides: &artifact.TypeInfoProvides{}},
+				TypeInfoV3: &artifact.TypeInfoV3{ArtifactProvides: artifact.TypeInfoProvides{}},
 				Augmented:  true,
 			},
 			verifyFunc: func(args ComposeHeaderArgs) { assert.Nil(t, args.TypeInfoV3) },
